function ExplicitHE(dx,dt)

% solve the heat equation using Explicit scheme
% solve Ut=Uxx for x in (0,1), t>0
%  U(0,t)=U(1,t)=0, u(x,0)=f(x)= 2x (when x<0.5), 2-2x (otherwise)


t=0.1; 
%exact solution:
ex=[0:0.01:1];  u_exact=zeros(size(ex));
for n=1:200,
  u_exact=u_exact+8/pi/pi*sin(n*pi/2)/n/n*exp(-(n*pi)^2*t)*sin(n*pi*ex);
end

m=round(1/dx)-1; N=round(t/dt); r=dt/(dx*dx)
x=[dx:dx:1-dx];    %all the inner grid points

%up is the previous solution and un is the next solution.
up=zeros(size(x)); un=zeros(size(x));

%initial condition:
for i=1:m,

  %%%%% change .5 to .25 to see discontinuous initial data
  if x(i)<0.5, 

    %%%%% along with .25 above, change 2 to 6 to see asymmetry
    up(i)=2*x(i);
  
  else 
    up(i)=2*(1-x(i));
  end
end


figure

% uncomment to plot initial data
plot(ex,u_exact,'-',x,up,'--r'); 

% uncomment to show all plots at once (probably not useful here)
hold on

%main loop for explicit scheme:
for i=1:N,
  for j=2:m-1,
    un(j) = r*up(j-1)+(1-2*r)*up(j)+r*up(j+1);
  end

  %take care of boundary conditions:
  un(1) = (1-2*r)*up(1)+r*up(2);
  un(m) = r*up(m-1)+(1-2*r)*up(m);

  % uncomment to show plot of each time step
  %plot(ex,u_exact,'-',x,up,'--o');
  %pause

  %set un to up:
  up=un;
end

p=plot(ex,u_exact,[0 x 1],[0 up 0],'--o');
h=text(0.2,0.05,sprintf('dx=%g, dt=%g, r=%g',dx,dt,r));
set(p,'LineWidth',1.2), set(h,'FontSize',18),

